<?php

/**
 * Enqueue scripts and styles.
 */
function process_management_scripts() {
	wp_enqueue_script( 'font-awesome', 'https://use.fontawesome.com/releases/v5.0.6/js/all.js', array() );
}
add_action( 'wp_enqueue_scripts', 'process_management_scripts' );

// Logs a process completion
add_action( 'wp_ajax_log_process', 'process_log_action_callback' );

function process_log_action_callback() {
	global $wpdb; // this is how you get access to the database

	$post_id = intval( $_POST['post_id'] );

	// Create post object
	$my_post = array(
		'post_status' => 'publish',
		'post_type'   => 'captcore_processlog',
		'post_author' => get_current_user_id(),
	);

	// Insert the post into the database
	$process_log_id = wp_insert_post( $my_post );

	// Debug output
	$redirect_url = get_permalink( $post_id );
	echo "{ \"redirect_url\" : \"$redirect_url\", \"process_id\": \"$process_log_id\" }";

	// Assign process to ACF relationship field
	update_field( 'process', $post_id, $process_log_id );

	wp_die(); // this is required to terminate immediately and return a proper response
}

// Register Custom Post Type
function process_post_type() {

	$labels       = array(
		'name'                  => _x( 'Processes', 'Post Type General Name', 'captaincore' ),
		'singular_name'         => _x( 'Process', 'Post Type Singular Name', 'captaincore' ),
		'menu_name'             => __( 'Processes', 'captaincore' ),
		'name_admin_bar'        => __( 'Process', 'captaincore' ),
		'archives'              => __( 'Process Archives', 'captaincore' ),
		'parent_item_colon'     => __( 'Parent Process:', 'captaincore' ),
		'all_items'             => __( 'Processes', 'captaincore' ),
		'add_new_item'          => __( 'Add New Process', 'captaincore' ),
		'add_new'               => __( 'Add New', 'captaincore' ),
		'new_item'              => __( 'New Process', 'captaincore' ),
		'edit_item'             => __( 'Edit Process', 'captaincore' ),
		'update_item'           => __( 'Update Process', 'captaincore' ),
		'view_item'             => __( 'View Process', 'captaincore' ),
		'search_items'          => __( 'Search Processes', 'captaincore' ),
		'not_found'             => __( 'Not found', 'captaincore' ),
		'not_found_in_trash'    => __( 'Not found in Trash', 'captaincore' ),
		'featured_image'        => __( 'Featured Image', 'captaincore' ),
		'set_featured_image'    => __( 'Set featured image', 'captaincore' ),
		'remove_featured_image' => __( 'Remove featured image', 'captaincore' ),
		'use_featured_image'    => __( 'Use as featured image', 'captaincore' ),
		'insert_into_item'      => __( 'Insert into process', 'captaincore' ),
		'uploaded_to_this_item' => __( 'Uploaded to this process', 'captaincore' ),
		'items_list'            => __( 'Processes list', 'captaincore' ),
		'items_list_navigation' => __( 'Processes list navigation', 'captaincore' ),
		'filter_items_list'     => __( 'Filter items list', 'captaincore' ),
	);
	$capabilities = array(
		'edit_post'          => 'process_edit_post',
		'read_post'          => 'process_read_post',
		'delete_post'        => 'process_delete_post',
		'edit_posts'         => 'process_edit_posts',
		'edit_others_posts'  => 'process_edit_others_posts',
		'publish_posts'      => 'process_publish_posts',
		'read_private_posts' => 'process_read_private_posts',
	);
	$args         = array(
		'label'               => __( 'Process', 'captaincore' ),
		'description'         => __( 'Process Description', 'captaincore' ),
		'labels'              => $labels,
		'supports'            => array( 'title', 'editor', 'author', 'thumbnail', 'revisions', 'wpcom-markdown' ),
		'hierarchical'        => false,
		'public'              => true,
		'show_ui'             => true,
		'show_in_menu'        => true,
		'menu_position'       => 5,
		'menu_icon'           => 'dashicons-controls-repeat',
		'show_in_admin_bar'   => true,
		'show_in_nav_menus'   => true,
		'can_export'          => true,
		'has_archive'         => false,
		'exclude_from_search' => true,
		'publicly_queryable'  => true,
		'capability_type'     => 'page',
		'capabilities'        => $capabilities,
		'map_meta_cap'        => true,
	);
	register_post_type( 'captcore_process', $args );

}
add_action( 'init', 'process_post_type', 0 );

// Register Custom Post Type
function process_log_post_type() {

	$labels       = array(
		'name'                  => _x( 'Process Logs', 'Post Type General Name', 'captaincore' ),
		'singular_name'         => _x( 'Process Log', 'Post Type Singular Name', 'captaincore' ),
		'menu_name'             => __( 'Process Logs', 'captaincore' ),
		'name_admin_bar'        => __( 'Process Log', 'captaincore' ),
		'archives'              => __( 'Process Log Archives', 'captaincore' ),
		'parent_item_colon'     => __( 'Parent Process Log:', 'captaincore' ),
		'all_items'             => __( 'Process Logs', 'captaincore' ),
		'add_new_item'          => __( 'Add New Process Log', 'captaincore' ),
		'add_new'               => __( 'Add New', 'captaincore' ),
		'new_item'              => __( 'New Process Log', 'captaincore' ),
		'edit_item'             => __( 'Edit Process Log', 'captaincore' ),
		'update_item'           => __( 'Update Process Log', 'captaincore' ),
		'view_item'             => __( 'View Process Log', 'captaincore' ),
		'search_items'          => __( 'Search Process Logs', 'captaincore' ),
		'not_found'             => __( 'Not found', 'captaincore' ),
		'not_found_in_trash'    => __( 'Not found in Trash', 'captaincore' ),
		'featured_image'        => __( 'Featured Image', 'captaincore' ),
		'set_featured_image'    => __( 'Set featured image', 'captaincore' ),
		'remove_featured_image' => __( 'Remove featured image', 'captaincore' ),
		'use_featured_image'    => __( 'Use as featured image', 'captaincore' ),
		'insert_into_item'      => __( 'Insert into process log', 'captaincore' ),
		'uploaded_to_this_item' => __( 'Uploaded to this process log', 'captaincore' ),
		'items_list'            => __( 'Process Logs list', 'captaincore' ),
		'items_list_navigation' => __( 'Process Logs list navigation', 'captaincore' ),
		'filter_items_list'     => __( 'Filter items list', 'captaincore' ),
	);
	$capabilities = array(
		'edit_post'          => 'process_edit_post',
		'read_post'          => 'process_read_post',
		'delete_post'        => 'process_delete_post',
		'edit_posts'         => 'process_edit_posts',
		'edit_others_posts'  => 'process_edit_others_posts',
		'publish_posts'      => 'process_publish_posts',
		'read_private_posts' => 'process_read_private_posts',
	);
	$args         = array(
		'label'               => __( 'Process Log', 'captaincore' ),
		'description'         => __( 'Process Log Description', 'captaincore' ),
		'labels'              => $labels,
		'supports'            => array( 'author', 'thumbnail', 'revisions' ),
		'hierarchical'        => false,
		'public'              => false,
		'show_ui'             => true,
		'show_in_menu'        => true,
		'menu_position'       => 5,
		'menu_icon'           => 'dashicons-media-spreadsheet',
		'show_in_admin_bar'   => true,
		'show_in_nav_menus'   => true,
		'can_export'          => true,
		'has_archive'         => true,
		'exclude_from_search' => true,
		'publicly_queryable'  => false,
		'capability_type'     => 'page',
		'show_in_rest'        => true,
		'capabilities'        => $capabilities,
		'map_meta_cap'        => true,
	);
	register_post_type( 'captcore_processlog', $args );

}
add_action( 'init', 'process_log_post_type', 0 );

function captaincore_process_init() {
	register_taxonomy(
		'process_role', array( 'captcore_process' ), array(
			'hierarchical'   => true,
			'label'          => 'Roles',
			'singular_label' => 'Role',
			'rewrite'        => true,
		)
	);
}

add_action( 'init', 'captaincore_process_init' );
